@@ -76,6 +76,12 @@ BacktraceWidget::BacktraceWidget(BacktraceGenerator *generator, QWidget *parent,
                           "install the missing debug symbols packages.")));
     ui.m_installDebugButton->setVisible(false);
     connect(ui.m_installDebugButton, &QPushButton::clicked, this, &BacktraceWidget::installDebugPackages);
+    if (DrKonqi::crashedApplication()->hasDeletedFiles()) {
+        ui.m_installDebugButton->setEnabled(false);
+        ui.m_installDebugButton->setToolTip(i18nc("@info:tooltip",
+                                                  "Symbol installation is unavailable because the application "
+                                                  "was updated or uninstalled after it had been started."));
+    }
 
     KGuiItem::assign(ui.m_copyButton, KGuiItem2(QString(), QIcon::fromTheme(QStringLiteral("edit-copy")),
                                           i18nc("@info:tooltip", "Use this button to copy the "
@@ -262,7 +268,7 @@ void BacktraceWidget::loadData()
                                     QLatin1String("#missingDebugPackages")));
                 ui.m_installDebugButton->setVisible(true);
                 //Retrieve the libraries with missing debug info
-                QStringList missingLibraries = btParser->librariesWithMissingDebugSymbols().toList();
+                QStringList missingLibraries = btParser->librariesWithMissingDebugSymbols().values();
                 m_debugPackageInstaller->setMissingLibraries(missingLibraries);
             } else {
                 //No automated method to install the missing debug info
@@ -389,7 +395,7 @@ void BacktraceWidget::extraDetailsLinkActivated(QString link)
     } else if (link == QLatin1String("#missingDebugPackages")) {
         BacktraceParser * btParser = m_btGenerator->parser();
 
-        QStringList missingDbgForFiles = btParser->librariesWithMissingDebugSymbols().toList();
+        QStringList missingDbgForFiles = btParser->librariesWithMissingDebugSymbols().values();
         missingDbgForFiles.insert(0, DrKonqi::crashedApplication()->executable().absoluteFilePath());
 
         //HTML message
