@@ -20,9 +20,8 @@
 
 #include "reportassistantpages_base.h"
 
-#include <QLabel>
 #include <QCheckBox>
-#include <QToolTip>
+#include <QFontDatabase>
 #include <QDesktopServices>
 
 #include <KToolInvocation>
@@ -130,6 +129,13 @@ bool CrashInformationPage::showNextPage()
 
 //BEGIN BugAwarenessPage
 
+static QHash<int, ReportInterface::Reproducible> s_reproducibleIndex {
+    { 0, ReportInterface::ReproducibleUnsure },
+    { 1, ReportInterface::ReproducibleNever },
+    { 2, ReportInterface::ReproducibleSometimes },
+    { 3, ReportInterface::ReproducibleEverytime }
+};
+
 BugAwarenessPage::BugAwarenessPage(ReportAssistantDialog * parent)
         : ReportAssistantPage(parent)
 {
@@ -144,10 +150,18 @@ BugAwarenessPage::BugAwarenessPage(ReportAssistantDialog * parent)
     // Also listen to toggle so radio buttons are covered.
     connect(ui.m_rememberGroup, static_cast<void (QButtonGroup::*)(int, bool)>(&QButtonGroup::buttonToggled), this, &BugAwarenessPage::updateCheckBoxes);
 
-    ui.m_appSpecificDetailsExamples->setVisible(reportInterface()->appDetailsExamples()->hasExamples());
-    ui.m_appSpecificDetailsExamples->setContextMenuPolicy(Qt::NoContextMenu);
+    ui.m_appSpecificDetailsExamplesWidget->setVisible(
+                reportInterface()->appDetailsExamples()->hasExamples());
+    ui.m_appSpecificDetailsExamples->setText(
+                i18nc("@label examples about information the user can provide",
+                      "Examples: %1", reportInterface()->appDetailsExamples()->examples()));
+    ui.m_appSpecificDetailsExamples->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 
-    connect(ui.m_appSpecificDetailsExamples, &QLabel::linkActivated, this, &BugAwarenessPage::showApplicationDetailsExamples);
+    if (qEnvironmentVariableIsSet("DRKONQI_TEST_MODE")) {
+        ui.m_rememberCrashSituationYes->setChecked(true);
+        ui.m_reproducibleBox->setCurrentIndex(
+                    s_reproducibleIndex.key(ReportInterface::ReproducibleEverytime));
+    }
 }
 
 void BugAwarenessPage::aboutToShow()
@@ -159,24 +173,7 @@ void BugAwarenessPage::aboutToHide()
 {
     //Save data
     ReportInterface::Reproducible reproducible = ReportInterface::ReproducibleUnsure;
-    switch(ui.m_reproducibleBox->currentIndex()) {
-        case 0: {
-            reproducible = ReportInterface::ReproducibleUnsure;
-            break;
-        }
-        case 1: {
-            reproducible = ReportInterface::ReproducibleNever;
-            break;
-        }
-        case 2: {
-            reproducible = ReportInterface::ReproducibleSometimes;
-            break;
-        }
-        case 3: {
-            reproducible = ReportInterface::ReproducibleEverytime;
-            break;
-        }
-    }
+    reproducible = s_reproducibleIndex.value(ui.m_reproducibleBox->currentIndex());
 
     reportInterface()->setBugAwarenessPageData(ui.m_rememberCrashSituationYes->isChecked(),
                                                reproducible,
@@ -200,14 +197,6 @@ void BugAwarenessPage::updateCheckBoxes()
     ui.m_appSpecificDetailsExamples->setEnabled(rememberSituation);
 }
 
-void BugAwarenessPage::showApplicationDetailsExamples()
-{
-    QToolTip::showText(QCursor::pos(),
-                       i18nc("@label examples about information the user can provide",
-                             "Examples: %1", reportInterface()->appDetailsExamples()->examples()),
-                       this);
-}
-
 //END BugAwarenessPage
 
 //BEGIN ConclusionPage
@@ -236,7 +225,8 @@ void ConclusionPage::finishClicked()
     if (m_needToReport && !m_isBKO) {
         const CrashedApplication *crashedApp = DrKonqi::crashedApplication();
         BugReportAddress reportAddress = crashedApp->bugReportAddress();
-        QString report = reportInterface()->generateReportFullText(false);
+        QString report = reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Exclude,
+                                                                   ReportInterface::Backtrace::Complete);
 
         if (reportAddress.isEmail()) {
             QString subject = QStringLiteral("[%1] [%2] Automatic crash report generated by DrKonqi");
@@ -410,7 +400,9 @@ void ConclusionPage::aboutToHide()
 void ConclusionPage::openReportInformation()
 {
     if (!m_infoDialog) {
-        QString info = reportInterface()->generateReportFullText(false) + QLatin1Char('\n') +
+        QString info = reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Exclude,
+                                                                 ReportInterface::Backtrace::Complete)
+                + QLatin1Char('\n') +
                             i18nc("@info report to url/mail address","Report to %1",
                                   DrKonqi::crashedApplication()->bugReportAddress());
 
